// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package impl

import (
	"context"
	"cp-system-management/impl/v1/log"
	"cp-system-management/impl/v1/organization"
	"cp-system-management/impl/v1/user"
	"cp-system-management/pb"
	pb_v1 "cp-system-management/pb/v1"

	"github.com/jaryhe/gopkgs/tasker/rpctasker"
	"google.golang.org/grpc"
)

// 具体实现
type Rcvr struct {
}

func Register(s *grpc.Server) {
	pb.RegisterSystemServer(s, &Rcvr{})
}

func (c *Rcvr) CreateUser(ctx context.Context, req *pb_v1.CreateUserRequest) (reply *pb_v1.CreateUserReply, err error) {
	t1 := func() error {
		reply, err = user.CreateUser(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

// 系统用户登录
func (c *Rcvr) Login(ctx context.Context, req *pb_v1.LoginRequest) (reply *pb_v1.LoginReply, err error) {
	t1 := func() error {
		reply, err = user.Login(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

// 修改密码
func (c *Rcvr) ChangePassword(ctx context.Context, req *pb_v1.ChangePasswordRequest) (reply *pb_v1.ChangePasswordReply, err error) {
	t1 := func() error {
		reply, err = user.ChangePassword(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

// 创建机构
func (c *Rcvr) CreateOrganization(ctx context.Context, req *pb_v1.CreateOrganizationRequest) (reply *pb_v1.CreateOrganizationReply, err error) {
	t1 := func() error {
		reply, err = organization.CreateOrganization(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

// 删除机构
func (c *Rcvr) DeleteOrganization(ctx context.Context, req *pb_v1.DeleteOrganizationRequest) (reply *pb_v1.DeleteOrganizationReply, err error) {
	t1 := func() error {
		reply, err = organization.DeleteOrganization(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

// 更新机构
func (c *Rcvr) UpdateOrganization(ctx context.Context, req *pb_v1.UpdateOrganizationRequest) (reply *pb_v1.UpdateOrganizationReply, err error) {
	t1 := func() error {
		reply, err = organization.UpdateOrganization(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

// 机构列表
func (c *Rcvr) OrganizationList(ctx context.Context, req *pb_v1.OrganizationListRequest) (reply *pb_v1.OrganizationListReply, err error) {
	t1 := func() error {
		reply, err = organization.OrganizationList(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

// 创建机构管理员账号
func (c *Rcvr) CreateOrganizationUser(ctx context.Context, req *pb_v1.CreateOrganizationUserRequest) (reply *pb_v1.CreateOrganizationUserReply, err error) {
	t1 := func() error {
		reply, err = organization.CreateOrganizationUser(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

// 机构管理员列表
func (c *Rcvr) OrganizationUserList(ctx context.Context, req *pb_v1.OrganizationUserListRequest) (reply *pb_v1.OrganizationUserListReply, err error) {
	t1 := func() error {
		reply, err = organization.OrganizationUserList(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

// 机构key证
func (c *Rcvr) OrganizationKeyAuth(ctx context.Context, req *pb_v1.OrganizationKeyAuthRequest) (reply *pb_v1.OrganizationKeyAuthReply, err error) {
	t1 := func() error {
		reply, err = organization.OrganizationKeyAuth(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

// 修改机构管理员
func (c *Rcvr) OrganizationUserUpdate(ctx context.Context, req *pb_v1.OrganizationUserUpdateRequest) (reply *pb_v1.OrganizationUserUpdateReply, err error) {
	t1 := func() error {
		reply, err = organization.OrganizationUserUpdate(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

// 暂时废弃
func (c *Rcvr) OrganizationUserResetPassword(ctx context.Context, req *pb_v1.OrganizationUserResetPasswordRequest) (reply *pb_v1.OrganizationUserResetPasswordReply, err error) {
	t1 := func() error {
		reply, err = organization.OrganizationUserResetPassword(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

// 添加操作日志
func (c *Rcvr) SystemLogAdd(ctx context.Context, req *pb_v1.SystemLogAddRequest) (reply *pb_v1.SystemLogAddReply, err error) {
	t1 := func() error {
		reply, err = log.SystemLogAdd(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) SystemLogList(ctx context.Context, req *pb_v1.SystemLogListRequest) (reply *pb_v1.SystemLogListReply, err error) {
	t1 := func() error {
		reply, err = log.SystemLogList(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}
