// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package log

import (
	"context"
	"cp-system-management/errors"
	dbmodel "cp-system-management/model"
	pb_v1 "cp-system-management/pb/v1"
	"encoding/json"
	"fmt"
	"time"

	"github.com/jaryhe/gopkgs/database"
	"github.com/jaryhe/gopkgs/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
)

//
func SystemLogAdd(ctx context.Context, req *pb_v1.SystemLogAddRequest) (reply *pb_v1.SystemLogAddReply, err error) {
	reply = &pb_v1.SystemLogAddReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()

	p := dbmodel.TLog{
		Uid:req.Uid,
		Username:req.Username,
		Action:req.Action,
		Module:req.Module,
		Origin:req.Origin,
		Target:req.Target,
		CreatedAt:time.Unix(req.CreatedAt, 0),
	}

	err = p.Insert(database.DB())
	if err != nil {
		return nil, errors.DataBaseError
	}
	return &pb_v1.SystemLogAddReply{}, nil
}
