// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package log

import (
	"context"
	"cp-system-management/errors"
	dbmodel "cp-system-management/model"
	pb_v1 "cp-system-management/pb/v1"
	"encoding/json"
	"fmt"
	"github.com/jaryhe/gopkgs/database"
	"github.com/jaryhe/gopkgs/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
	"time"
)

//
func SystemLogList(ctx context.Context, req *pb_v1.SystemLogListRequest) (reply *pb_v1.SystemLogListReply, err error) {
	reply = &pb_v1.SystemLogListReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()

	if req.PageSize == 0 {
		req.PageSize = 10
	}
	if req.Page == 0 {
		req.Page = 1
	}
	p := &dbmodel.TLog{}
	where := map[string]interface{}{}
	or := map[string]interface{}{}
	if req.Action != "" {
		where["action"] = req.Action
	}
	if req.Module != "" {
		where["module"] = req.Module
	}
	if req.Username != "" {
		where["username like"] = "%"+req.Username+"%"
	}
	if req.Start > 0 {
		where["created_at >="] = time.Unix(req.Start, 0).Format("2006-01-02 15:04:05")
	}
	if req.End > 0 {
		where["created_at <"] = time.Unix(req.End, 0).Format("2006-01-02 15:04:05")
	}
	if req.Filter != "" {
		or["target like"] = "%"+req.Filter+"%"
		or["origin like"] = "%"+req.Filter+"%"
	}

	total, err := p.Count(database.DB(), where, or)
	if err != nil {
		return nil, errors.DataBaseError
	}
	reply.Total = total
	reply.Page = req.Page
	if total == 0 {
		return reply, nil
	}
	list, err := p.List(database.DB(), where, or, req.PageSize, (req.Page-1)*req.PageSize)
	if err != nil {
		return nil, errors.DataBaseError
	}
	reply.List = make([]*pb_v1.SystemLogItem, len(list))
	for i, v := range list {
		reply.List[i] = &pb_v1.SystemLogItem{
			Id:v.ID,
			Action:v.Action,
			Module:v.Module,
			Username:v.Username,
			Uid:v.Uid,
			Origin:v.Origin,
			Target:v.Target,
			CreatedAt:v.CreatedAt.Format("2006-01-02 15:04:05"),
		}
	}

	return reply, nil
}
