// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.
package organization

import (
	"context"
	"cp-system-management/errors"
	dbmodel "cp-system-management/model"
	"cp-system-management/pb"
	pb_v1 "cp-system-management/pb/v1"
	"encoding/json"
	"fmt"

	"github.com/jaryhe/gopkgs/database"
	"github.com/jaryhe/gopkgs/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
)

// 创建机构超级管理员
func CreateOrganizationUser(ctx context.Context, req *pb_v1.CreateOrganizationUserRequest) (reply *pb_v1.CreateOrganizationUserReply, err error) {
	reply = &pb_v1.CreateOrganizationUserReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()

	// 获取基础rbac节点，传递给origanizaiton服务
	rbacNode := &dbmodel.RbacBaseNode{}
	nodeList := []dbmodel.RbacBaseNode{}
	err = rbacNode.QueryAll(database.DB(), nil, &nodeList)
	if err != nil {
		return reply, errors.DataBaseError
	}

	rReq := &pb_v1.CreateManagementUserRequest{
		OrganizationCode: req.OrganizationCode,
		Username:     req.Username,
		Password:     req.Password,
		Phone:        req.Phone,
		Email:        req.Email,
		Zones: "001",
		IsSupperUser: true}

	for _, v := range nodeList {
		node := &pb_v1.RbacNode{}
		node.Id = v.Id
		node.Name = v.Name
		node.Pid = v.Pid
		node.Method = v.Method
		node.Object = v.Object
		node.Resource = v.Resource
		node.Router = v.Resource
		node.IsSuper = v.IsSuper

		rReq.RbacNodeList = append(rReq.RbacNodeList, node)
	}

	rRep, err := pb.Organization.CreateManagementUser(ctx, rReq)
	if err != nil {
		return reply, err
	}

	reply.Uid = rRep.Uid

	return reply, nil
}
