// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package organization

import (
	"context"
	"cp-system-management/errors"
	dbmodel "cp-system-management/model"
	pb_v1 "cp-system-management/pb/v1"
	"encoding/json"
	"fmt"

	"github.com/jinzhu/gorm"

	"github.com/jaryhe/gopkgs/database"
	"github.com/jaryhe/gopkgs/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
)

// 创建机构
func DeleteOrganization(ctx context.Context, req *pb_v1.DeleteOrganizationRequest) (reply *pb_v1.DeleteOrganizationReply, err error) {
	reply = &pb_v1.DeleteOrganizationReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()

	if req.OrganizationCode == "" {
		return reply, status.Error(10003, "参数错误，机构名为空")
	}

	p := &dbmodel.Organization{}
	where := map[string]interface{}{"organization_code": req.OrganizationCode}
	db := database.DB()

	// 查找是否存在
	err = p.Find(db, where)
	if err != nil {
		if err == gorm.ErrRecordNotFound {
			return reply, errors.OrganizationNotExist
		}
		return reply, errors.DataBaseError
	}

	// 删除
	err = p.Delete(db, nil)
	if err != nil {
		return reply, errors.DataBaseError
	}

	return reply, nil
}
