// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package organization

import (
	"context"
	"cp-system-management/errors"
	dbmodel "cp-system-management/model"
	pb_v1 "cp-system-management/pb/v1"
	"encoding/json"
	"fmt"
	"github.com/jaryhe/gopkgs/database"
	"github.com/jaryhe/gopkgs/logger"
	"github.com/jinzhu/gorm"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
)

// 机构列表
func OrganizationKeyAuth(ctx context.Context, req *pb_v1.OrganizationKeyAuthRequest) (reply *pb_v1.OrganizationKeyAuthReply, err error) {
	reply = &pb_v1.OrganizationKeyAuthReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()

	p := dbmodel.Organization{}
	where := map[string]interface{}{
		"key":req.Key,
	}
	err = p.Find(database.DB(), where)
	if err != nil {
		if err == gorm.ErrRecordNotFound {
			return nil, errors.OrganizationNotExist
		}
		return nil, errors.DataBaseError
	}
	reply.OrganizationCode = p.OrganizationCode
	reply.OrganizationName = p.OrganizationName
	reply.EndTime = p.EndTime
	reply.IsDisable = p.IsDisable


	return reply, nil
}
