// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package organization

import (
	"context"
	"cp-system-management/errors"
	dbmodel "cp-system-management/model"
	pb_v1 "cp-system-management/pb/v1"
	"encoding/json"
	"fmt"
	"time"

	"github.com/jaryhe/gopkgs/database"
	"github.com/jaryhe/gopkgs/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
)

// 机构列表
func OrganizationList(ctx context.Context, req *pb_v1.OrganizationListRequest) (reply *pb_v1.OrganizationListReply, err error) {
	reply = &pb_v1.OrganizationListReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()
	if req.PageSize == 0 {
		req.PageSize = 1
	}
	if req.Page == 0 {
		req.Page = 1
	}

	p := &dbmodel.Organization{}
	db := database.DB()
	reply.Total, err = p.Count(db)
	reply.Page = req.Page
	if reply.Total == 0 {
		return reply, nil
	}
	where := map[string]interface{}{}
	if req.Filter != "" {
		where["organization_name like"] = "%" + req.Filter + "%"
	} else {
		where = nil
	}
	list, err := p.List(db, where, nil, req.PageSize, (req.Page-1)*req.PageSize)
	if err != nil {
		return reply, errors.DataBaseError
	}

	now := time.Now().Unix()
	for _, v := range list {
		organization := &pb_v1.Organization{}
		organization.IsDisable = v.IsDisable
		organization.EndTime = v.EndTime
		organization.Key = v.Key
		if now < v.EndTime {
			organization.EndTime = ((v.EndTime-now)/3600)/24 + 1
		}

		organization.OrganizationName = v.OrganizationName
		organization.OrganizationCode = v.OrganizationCode

		if now > v.EndTime {
			organization.IsExpire = true
		}

		reply.List = append(reply.List, organization)
	}

	return reply, nil
}
