// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.
package organization

import (
	"context"
	"cp-system-management/errors"
	"cp-system-management/pb"
	pb_v1 "cp-system-management/pb/v1"
	"encoding/json"
	"fmt"

	"github.com/jaryhe/gopkgs/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
)

//
func OrganizationUserList(ctx context.Context, req *pb_v1.OrganizationUserListRequest) (reply *pb_v1.OrganizationUserListReply, err error) {
	reply = &pb_v1.OrganizationUserListReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()

	if req.OrganizationCode == ""{
		return nil, errors.ParamsError
	}
	rReq := &pb_v1.ManagementSuperUserListRequest{
		OrganizationCode: req.OrganizationCode,
		Page:req.Page,
		PageSize:req.PageSize,
	}

	rRep, err := pb.Organization.ManagementSuperUserList(ctx, rReq)
	if err != nil {
		return reply, errors.ServiceError
	}
	reply.Page = rRep.Page
	reply.Total = rRep.Total
	reply.List = make([]*pb_v1.OrganizationUserItem, len(rRep.List))
	for i, v := range rRep.List {
		item := &pb_v1.OrganizationUserItem{
			OrganizationCode:req.OrganizationCode,
			Email:v.Email,
			Phone:v.Phone,
			Id:v.Id,
			Username:v.Username,
			CreatedAt:v.CreatedAt,
		}
		reply.List[i] = item
	}

	return reply, nil
}
