// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package user

import (
	"context"
	"cp-system-management/consts"
	"cp-system-management/errors"
	dbmodel "cp-system-management/model"
	pb_v1 "cp-system-management/pb/v1"
	"encoding/json"
	"fmt"

	"github.com/jaryhe/gopkgs/util"

	"github.com/jinzhu/gorm"

	"github.com/jaryhe/gopkgs/database"
	"github.com/jaryhe/gopkgs/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
)

// 修改密码
func ChangePassword(ctx context.Context, req *pb_v1.ChangePasswordRequest) (reply *pb_v1.ChangePasswordReply, err error) {
	reply = &pb_v1.ChangePasswordReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()

	if req.Uid <= 0 || req.Password == "" {
		return reply, errors.ParamsError
	}

	p := &dbmodel.SystemUser{}
	db := database.DB()

	where := map[string]interface{}{
		"id": req.Uid,
	}

	// 查找用户是否存在
	err = p.Find(db, where)
	if err != nil && err != gorm.ErrRecordNotFound {
		if err == gorm.ErrRecordNotFound {
			return reply, errors.UserNotExist
		}
		return reply, errors.DataBaseError
	}

	oldpasswd, _ := util.GetMd5Pass(req.Old, consts.CRYPTO_KEY)
	if oldpasswd != p.Password {
		return nil, errors.PasswordError
	}
	// 更新密码
	passwd, _ := util.GetMd5Pass(req.Password, consts.CRYPTO_KEY)
	p.Password = passwd
	err = p.Update(database.DB())
	if err != nil {
		return reply, errors.DataBaseError
	}
	return reply, nil
}
