// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package user

import (
	"context"
	"cp-system-management/consts"
	"cp-system-management/errors"
	dbmodel "cp-system-management/model"
	pb_v1 "cp-system-management/pb/v1"
	"encoding/json"
	"fmt"

	"github.com/jinzhu/gorm"

	"github.com/jaryhe/gopkgs/database"
	"github.com/jaryhe/gopkgs/logger"
	"github.com/jaryhe/gopkgs/util"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
)

// 手机号登录
func Login(ctx context.Context, req *pb_v1.LoginRequest) (reply *pb_v1.LoginReply, err error) {
	reply = &pb_v1.LoginReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()

	if req.Username == "" || req.Password == "" {
		return reply, errors.ParamsError
	}

	p := &dbmodel.SystemUser{}
	db := database.DB()

	where := map[string]interface{}{
		"username": req.Username,
	}

	//  查找用户是否存在
	err = p.Find(db, where)
	if err != nil {
		if err == gorm.ErrRecordNotFound {
			return reply, errors.UserNotExist
		}
		return reply, errors.DataBaseError
	}
	passwd, _ := util.GetMd5Pass(req.Password, consts.CRYPTO_KEY)
	if passwd != p.Password {
		return reply, errors.PasswordError
	}

	reply.Uid = p.Id

	return reply, nil
}
